@@ -21,41 +21,34 @@
 #
 # ---------------------------------------------------------------------------##
 
-
-# imports
-import os
 import locale
+import os
 
-# PySol imports
+from pysollib.gamedb import GI
+from pysollib.help import help_about, help_html
 from pysollib.mfxutil import Struct, openURL
 from pysollib.mfxutil import print_err
-from pysollib.pysolrandom import constructRandom
-from pysollib.settings import TITLE, PACKAGE_URL
-from pysollib.settings import TOP_TITLE
-from pysollib.settings import DEBUG
-from pysollib.gamedb import GI
-
-# stats imports
-from pysollib.stats import FileStatsFormatter
-from pysollib.pysoltk import SingleGame_StatsDialog, AllGames_StatsDialog
-from pysollib.pysoltk import FullLog_StatsDialog, SessionLog_StatsDialog
-from pysollib.pysoltk import Status_StatsDialog, Top_StatsDialog
-from pysollib.pysoltk import ProgressionDialog
-from pysollib.pysoltk import GameInfoDialog
-
-# toolkit imports
 from pysollib.mygettext import _
-from pysollib.pysoltk import MfxMessageDialog, MfxSimpleEntry
-from pysollib.pysoltk import MfxExceptionDialog
-from pysollib.pysoltk import PlayerOptionsDialog
-from pysollib.pysoltk import TimeoutsDialog
+from pysollib.pysolrandom import constructRandom
+from pysollib.pysoltk import AllGames_StatsDialog, SingleGame_StatsDialog
 from pysollib.pysoltk import ColorsDialog
-from pysollib.pysoltk import FontsDialog
 from pysollib.pysoltk import EditTextDialog
+from pysollib.pysoltk import FontsDialog
+from pysollib.pysoltk import FullLog_StatsDialog, SessionLog_StatsDialog
+from pysollib.pysoltk import GameInfoDialog
+from pysollib.pysoltk import MfxExceptionDialog
+from pysollib.pysoltk import MfxMessageDialog, MfxSimpleEntry
+from pysollib.pysoltk import PlayerOptionsDialog
+from pysollib.pysoltk import ProgressionDialog
+from pysollib.pysoltk import PysolMenubarTk, PysolToolbarTk
+from pysollib.pysoltk import Status_StatsDialog, Top_StatsDialog
+from pysollib.pysoltk import TimeoutsDialog
 from pysollib.pysoltk import create_find_card_dialog
 from pysollib.pysoltk import create_solver_dialog
-from pysollib.pysoltk import PysolMenubarTk, PysolToolbarTk
-from pysollib.help import help_about, help_html
+from pysollib.settings import DEBUG
+from pysollib.settings import PACKAGE_URL, TITLE
+from pysollib.settings import TOP_SIZE
+from pysollib.stats import FileStatsFormatter
 
 
 # ************************************************************************
@@ -337,7 +330,7 @@ class PysolMenubar(PysolMenubarTk):
             elif type == 'not played' and won+lost == 0:
                 games.append(gi.id)
         if games:
-            game_id = self.app.getRandomGameId(games)
+            game_id = self.app.chooseRandomOutOfGames(games)
         if game_id and game_id != self.game.id:
             self.game.endGame()
             self.game.quitGame(game_id)
@@ -388,7 +381,7 @@ class PysolMenubar(PysolMenubarTk):
         if self._cancelDrag():
             return
         if self.changed():
-            if not self.game.areYouSure(_("Quit ") + TITLE):
+            if not self.game.areYouSure(_("Quit %s") % TITLE):
                 return
         self.game.endGame()
         self.game.quitGame()
@@ -452,7 +445,7 @@ class PysolMenubar(PysolMenubarTk):
         if not self.game.gsaveinfo.bookmarks:
             return
         if not self.game.areYouSure(_("Clear bookmarks"),
-                                    _("Clear all bookmarks ?")):
+                                    _("Clear all bookmarks?")):
             return
         self.game.gsaveinfo.bookmarks = {}
         self.game.updateMenus()
@@ -464,7 +457,7 @@ class PysolMenubar(PysolMenubarTk):
             return
         if self.changed(restart=1):
             if not self.game.areYouSure(_("Restart game"),
-                                        _("Restart this game ?")):
+                                        _("Restart this game?")):
                 return
         self.game.restartGame()
 
@@ -508,10 +501,11 @@ class PysolMenubar(PysolMenubarTk):
         if self._cancelDrag(break_pause=False):
             return
         game, gi = self.game, self.game.gameinfo
-        t = " " + game.getGameNumber(format=1)
-        cc = _("Comments for %s:\n\n") % (gi.name + t)
+        kw = {'game': gi.name,
+              'id': game.getGameNumber(format=1)}
+        cc = _("Comments for %(game)s %(id)s:\n\n") % kw
         c = game.gsaveinfo.comment or cc
-        d = EditTextDialog(game.top, _("Comments for ")+t, text=c)
+        d = EditTextDialog(game.top, _("Comments for %(id)s") % kw, text=c)
         if d.status == 0 and d.button == 0:
             text = d.text
             if text.strip() == cc.strip():
@@ -525,18 +519,16 @@ class PysolMenubar(PysolMenubarTk):
                     text += os.linesep
                 enc = locale.getpreferredencoding()
                 try:
-                    fd = open(fn, 'a')
-                    fd.write(text.encode(enc, 'replace'))
+                    open(fn, 'a').write(text.encode(enc, 'replace'))
                 except Exception as err:
                     d = MfxExceptionDialog(
                         self.top, err,
                         text=_("Error while writing to file"))
                 else:
-                    if fd:
-                        fd.close()
                     d = MfxMessageDialog(
-                        self.top, title=TITLE+_(" Info"), bitmap="info",
-                        text=_("Comments were appended to\n\n") + fn)
+                        self.top, title=_("%s Info") % TITLE, bitmap="info",
+                        text=_("Comments were appended to\n\n%(filename)s")
+                        % {'filename': fn})
         self._setCommentMenu(bool(game.gsaveinfo.comment))
 
     #
@@ -544,29 +536,23 @@ class PysolMenubar(PysolMenubarTk):
     #
 
     def _mStatsSave(self, player, filename, write_method):
-        file = None
         if player is None:
-            text = _("Demo statistics")
+            text = _("Demo statistics were appended to\n\n%(filename)s")
             filename = filename + "_demo"
         else:
-            text = _("Your statistics")
+            text = _("Your statistics were appended to\n\n%(filename)s")
         filename = os.path.join(self.app.dn.config, filename + ".txt")
         filename = os.path.normpath(filename)
         try:
-            file = open(filename, "a")
-            a = FileStatsFormatter(self.app, file)
+            a = FileStatsFormatter(self.app, open(filename, "a"))
             write_method(a, player)
         except EnvironmentError as ex:
-            if file:
-                file.close()
             MfxExceptionDialog(self.top, ex,
                                text=_("Error while writing to file"))
         else:
-            if file:
-                file.close()
             MfxMessageDialog(
-                self.top, title=TITLE+_(" Info"), bitmap="info",
-                text=text + _(" were appended to\n\n") + filename)
+                self.top, title=_("%s Info") % TITLE, bitmap="info",
+                text=text % {'filename': filename})
 
     def mPlayerStats(self, *args, **kw):
         mode = kw.get("mode", 101)
@@ -580,31 +566,40 @@ class PysolMenubar(PysolMenubarTk):
             d = Struct(status=-1, button=-1)
             if demo:
                 player = None
-                p0, p1, p2 = TITLE+_(" Demo"), TITLE+_(" Demo "), ""
             else:
                 player = self.app.opt.player
-                p0, p1, p2 = player, "", _(" for ") + player
             n = self.game.gameinfo.name
+            # translation keywords
+            transkw = {'app': TITLE,
+                       'player': player,
+                       'game': n,
+                       'tops': TOP_SIZE}
             #
             if mode == 100:
                 d = Status_StatsDialog(self.top, game=self.game)
             elif mode == 101:
-                header = p1 + _("Statistics for ") + n
+                header = (_("%(app)s Demo Statistics for %(game)s") if demo
+                          else _("Statistics for %(game)s")) % transkw
                 d = SingleGame_StatsDialog(
                    self.top, header, self.app, player, gameid=self.game.id)
                 gameid = d.selected_game
             elif mode == 102:
-                header = p1 + _("Statistics") + p2
+                header = (_("%(app)s Demo Statistics") if demo
+                          else _("Statistics for %(player)s")) % transkw
                 d = AllGames_StatsDialog(self.top, header, self.app, player)
                 gameid = d.selected_game
             elif mode == 103:
-                header = p1 + _("Full log") + p2
+                header = (_("%(app)s Demo Full log") if demo
+                          else _("Full log for %(player)s")) % transkw
                 d = FullLog_StatsDialog(self.top, header, self.app, player)
             elif mode == 104:
-                header = p1 + _("Session log") + p2
+                header = (_("%(app)s Demo Session log") if demo
+                          else _("Session log for %(player)s")) % transkw
                 d = SessionLog_StatsDialog(self.top, header, self.app, player)
             elif mode == 105:
-                header = p1 + TOP_TITLE + _(" for ") + n
+                # TRANSLATORS: eg. top 10 or top 5 results for a certain game
+                header = (_("%(app)s Demo Top %(tops)d for %(game)s") if demo
+                          else _("Top %(tops)d for %(game)s")) % transkw
                 d = Top_StatsDialog(
                     self.top, header, self.app, player, gameid=self.game.id)
             elif mode == 106:
@@ -630,7 +625,8 @@ class PysolMenubar(PysolMenubarTk):
                 # reset all player stats
                 if self.game.areYouSure(
                     _("Reset all statistics"),
-                    _("Reset ALL statistics and logs for player\n%s ?") % p0,
+                    _("Reset ALL statistics and logs for player\n" +
+                      "%(player)s?") % transkw,
                     confirm=1, default=1
                 ):
                     self.app.stats.resetStats(player, 0)
@@ -640,8 +636,8 @@ class PysolMenubar(PysolMenubarTk):
                 # reset player stats for current game
                 if self.game.areYouSure(
                     _("Reset game statistics"),
-                    _('Reset statistics and logs ' +
-                        'for player\n%s\nand game\n%s ?') % (p0, n),
+                    _('Reset statistics and logs for player\n%(player)s\n'
+                      'and game\n%(game)s?') % transkw,
                     confirm=1, default=1
                 ):
                     self.app.stats.resetStats(player, self.game.id)
