@@ -21,24 +21,23 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-import sys
 import os
+import sys
 import traceback
 
-# PySol imports
-from pysollib.mfxutil import print_err
-from pysollib.resource import CSI
-from pysollib.configobj import configobj, validate
+import configobj
+
 import pysollib.settings
-
-# Toolkit imports
-from pysollib.pysoltk import TOOLBAR_BUTTONS, TOOLKIT
-
+from pysollib.mfxutil import print_err
 from pysollib.mygettext import _
+from pysollib.mygettext import myGettext
+from pysollib.pysoltk import TOOLBAR_BUTTONS, TOOLKIT
+from pysollib.resource import CSI
 
-if sys.version_info > (3,):
-    unicode = str
+
+import six
+
+import validate
 
 # ************************************************************************
 # * Options
@@ -113,7 +112,10 @@ translate_game_names = boolean
 solver_presets = string_list
 solver_show_progress = boolean
 solver_max_iterations = integer
+solver_iterations_output_step = integer
+solver_preset = string
 display_win_message = boolean
+language = string
 
 [sound_samples]
 move = boolean
@@ -249,10 +251,13 @@ class Options:
         ('solver_presets', 'list'),
         ('solver_show_progress', 'bool'),
         ('solver_max_iterations', 'int'),
+        ('solver_iterations_output_step', 'int'),
+        ('solver_preset', 'string'),
         # ('toolbar_vars', 'list'),
         # ('recent_gameid', 'list'),
         # ('favorite_gameid', 'list'),
         ('display_win_message', 'bool'),
+        ('language', 'str'),
         ]
 
     def __init__(self):
@@ -320,6 +325,7 @@ class Options:
         self.negative_bottom = True
         self.translate_game_names = True
         self.display_win_message = True
+        self.language = ''
         # sound
         self.sound = True
         self.sound_mode = 1
@@ -432,6 +438,8 @@ class Options:
             ]
         self.solver_show_progress = True
         self.solver_max_iterations = 100000
+        self.solver_iterations_output_step = 100
+        self.solver_preset = 'video-editing'
 
     def setDefaults(self, top=None):
         WIN_SYSTEM = pysollib.settings.WIN_SYSTEM
@@ -513,7 +521,7 @@ class Options:
             val = getattr(self, key)
             if isinstance(val, str):
                 if sys.version_info < (3,):
-                    val = unicode(val, 'utf-8')
+                    val = six.text_type(val, 'utf-8')
             config['general'][key] = val
 
         config['general']['recent_gameid'] = self.recent_gameid
@@ -662,6 +670,8 @@ class Options:
             for key in TOOLBAR_BUTTONS:
                 self.toolbar_vars[key] = (key in visible_buttons)
 
+        myGettext.language = self.language
+
         # solver
         solver_presets = self._getOption('general', 'solver_presets', 'list')
         if solver_presets is not None:
