@@ -23,97 +23,13 @@
 
 
 # imports
-import sys
 import re
-import time
-from pysollib.mfxutil import SubclassResponsibility
-try:
-    import random2
-except ImportError:
-    raise ImportError(
-        "You need to install " +
-        "https://pypi.python.org/pypi/random2 using pip or similar.")
 
-
-if sys.version_info > (3,):
-    long = int
-
-# ************************************************************************
-# * Abstract class for PySol Random number generator.
-# *
-# * We use a seed of type long in the range [0, MAX_SEED].
-# ************************************************************************
-
-
-class BasicRandom:
-    # MAX_SEED = 0L
-    # MAX_SEED = 0xffffffffffffffffL  # 64 bits
-    MAX_SEED = long('100000000000000000000')  # 20 digits
-
-    ORIGIN_UNKNOWN = 0
-    ORIGIN_RANDOM = 1
-    ORIGIN_PREVIEW = 2         # random from preview
-    ORIGIN_SELECTED = 3         # manually entered
-    ORIGIN_NEXT_GAME = 4        # "Next game number"
-
-    def __init__(self):
-        self.seed_as_string = None
-
-    def getSeedStr(self):
-        return str(self.initial_seed)
-
-    def __str__(self):
-        return self.str(self.initial_seed)
-
-    def str(self, seed):
-        return '%020d' % seed
-
-    def reset(self):
-        raise SubclassResponsibility
-
-    def copy(self):
-        random = self.__class__(long(0))
-        random.__dict__.update(self.__dict__)
-        return random
-
-    def increaseSeed(self, seed):
-        if seed < self.MAX_SEED:
-            return seed + long(1)
-        return long(0)
-
-    def _getRandomSeed(self):
-        t = long(time.time() * 256.0)
-        t = (t ^ (t >> 24)) % (self.MAX_SEED + long(1))
-        return t
-
-    def setSeedAsStr(self, new_s):
-        self.seed_as_string = new_s
-
-    def getSeedAsStr(self):
-        if self.seed_as_string:
-            return self.seed_as_string
-        else:
-            return str(self)
-
-
-# ************************************************************************
-# * Mersenne Twister random number generator
-# * uses the standard python module `random'
-# ************************************************************************
-
-class MTRandom(BasicRandom, random2.Random):
-
-    def __init__(self, seed=None):
-        if seed is None:
-            seed = self._getRandomSeed()
-        BasicRandom.__init__(self)
-        random2.Random.__init__(self, seed)
-        self.initial_seed = seed
-        self.initial_state = self.getstate()
-        self.origin = self.ORIGIN_UNKNOWN
-
-    def reset(self):
-        self.setstate(self.initial_state)
+import pysol_cards
+assert getattr(pysol_cards, 'VERSION', (0, 0, 0)) >= (0, 8, 7), (
+    "Newer version of https://pypi.org/project/pysol-cards is required.")
+from pysol_cards.random_base import RandomBase  # noqa: I100
+from pysol_cards.random import MTRandom, match_ms_deal_prefix  # noqa: I100
 
 
 # ************************************************************************
@@ -121,12 +37,12 @@ class MTRandom(BasicRandom, random2.Random):
 # * uses the standard python module `random'
 # ************************************************************************
 
-# class WHRandom(BasicRandom, random.WichmannHill):
+# class WHRandom(RandomBase, random.WichmannHill):
 #
 #     def __init__(self, seed=None):
 #         if seed is None:
 #             seed = self._getRandomSeed()
-#         BasicRandom.__init__(self)
+#         RandomBase.__init__(self)
 #         random.WichmannHill.__init__(self, seed)
 #         self.initial_seed = seed
 #         self.initial_state = self.getstate()
@@ -140,10 +56,10 @@ class MTRandom(BasicRandom, random2.Random):
 # ************************************************************************
 
 
-class MFXRandom(BasicRandom):
+class MFXRandom(RandomBase):
 
     def __init__(self, seed=None):
-        BasicRandom.__init__(self)
+        RandomBase.__init__(self)
         if seed is None:
             seed = self._getRandomSeed()
         self.initial_seed = self.setSeed(seed)
@@ -156,7 +72,7 @@ class MFXRandom(BasicRandom):
         return self.seed
 
     def setSeed(self, seed):
-        seed = long(seed)
+        seed = int(seed)
         if not (0 <= seed <= self.MAX_SEED):
             raise ValueError("seed out of range")
         self.seed = seed
@@ -175,20 +91,9 @@ class MFXRandom(BasicRandom):
     def choice(self, seq):
         return seq[int(self.random() * len(seq))]
 
-    # Get a random integer in the range [a, b] including both end points.
-    def randint(self, a, b):
-        return a + long(self.random() * (b+1-a))
-
     def randrange(self, a, b):
         return self.randint(a, b-1)
 
-    def shuffle(self, seq):
-        n = len(seq) - 1
-        while n > 0:
-            j = self.randint(0, n)
-            seq[n], seq[j] = seq[j], seq[n]
-            n -= 1
-
 
 # ************************************************************************
 # * Linear Congruential random generator
@@ -201,15 +106,15 @@ class MFXRandom(BasicRandom):
 class LCRandom64(MFXRandom):
 
     def random(self):
-        self.seed = (self.seed*long('6364136223846793005') + 1) & self.MAX_SEED
+        self.seed = (self.seed*int('6364136223846793005') + 1) & self.MAX_SEED
         return ((self.seed >> 21) & 0x7fffffff) / 2147483648.0
 
 
-MS_LONG_BIT = (long(1) << 1000)
-CUSTOM_BIT = (long(1) << 999)
+MS_LONG_BIT = (1 << 1000)
+CUSTOM_BIT = (1 << 999)
 
 
-class CustomRandom(BasicRandom):
+class CustomRandom(RandomBase):
     def __init__(self):
         self.initial_seed = self.seed = MS_LONG_BIT | CUSTOM_BIT
         self.origin = self.ORIGIN_UNKNOWN
@@ -235,21 +140,27 @@ class CustomRandom(BasicRandom):
 
 
 class LCRandom31(MFXRandom):
-    MAX_SEED = long('0x1ffffffff', 0)          # 33 bits
+    MAX_SEED = int('0x1ffffffff', 0)          # 33 bits
+
+    def increaseSeed(self, seed):
+        ret = super(LCRandom31, self).increaseSeed(seed)
+        return "ms{}".format(ret)
 
     def getSeedStr(self):
         return "ms" + str(self.initial_seed)
 
     def str(self, seed):
-        return "%05d" % int(seed)
+        if match_ms_deal_prefix("{}".format(seed)) is None:
+            return "%05d" % int(seed)
+        return seed
 
     def setSeed(self, seed):
-        seed = long(seed)
+        seed = int(seed)
         self.seed = seed
         if not (0 <= seed <= self.MAX_SEED):
             raise ValueError("seed out of range")
-        self.seedx = (seed if (seed < long('0x100000000', 0)) else
-                      (seed - long('0x100000000', 0)))
+        self.seedx = (seed if (seed < int('0x100000000', 0)) else
+                      (seed - int('0x100000000', 0)))
         return seed
 
     def _rando(self):
@@ -269,13 +180,6 @@ class LCRandom31(MFXRandom):
 
         return a + (ret % (b+1-a))
 
-    def shuffle(self, seq):
-        n = len(seq) - 1
-        while n > 0:
-            j = self.randint(0, n)
-            seq[n], seq[j] = seq[j], seq[n]
-            n -= 1
-
     def reset(self):
         self.setSeed(self.seed)
 
@@ -290,30 +194,26 @@ PysolRandom = MTRandom
 # * PySol support code
 # ************************************************************************
 
-def _match_ms(s):
-    """match an ms based seed string."""
-    return re.match(r"ms([0-9]+)\n?\Z", s)
-
 
 # construct Random from seed string
 def constructRandom(s):
     if s == 'Custom':
         return CustomRandom()
-    m = _match_ms(s)
-    if m:
-        seed = long(m.group(1))
+    m = match_ms_deal_prefix(s)
+    if m is not None:
+        seed = m
         if 0 <= seed <= LCRandom31.MAX_SEED:
             ret = LCRandom31(seed)
             ret.setSeedAsStr(s)
             return ret
         else:
             raise ValueError("ms seed out of range")
-    # cut off "L" from possible conversion to long
+    # cut off "L" from possible conversion to int
     s = re.sub(r"L$", "", str(s))
     s = re.sub(r"[\s\#\-\_\.\,]", "", s.lower())
     if not s:
         return None
-    seed = long(s)
+    seed = int(s)
     if 0 <= seed < 32000:
         return LCRandom31(seed)
     return PysolRandom(seed)
@@ -322,11 +222,11 @@ def constructRandom(s):
 def random__str2long(s):
     if s == 'Custom':
         return CUSTOM_BIT | MS_LONG_BIT
-    m = _match_ms(s)
-    if m:
-        return (long(m.group(1)) | MS_LONG_BIT)
+    m = match_ms_deal_prefix(s)
+    if m is not None:
+        return (m | MS_LONG_BIT)
     else:
-        return long(s)
+        return int(s)
 
 
 def random__long2str(l):
