@@ -32,8 +32,8 @@ PACKAGE = 'PySolFC'
 TITLE = 'PySol'
 PACKAGE_URL = 'http://pysolfc.sourceforge.net/'
 
-VERSION = '2.4.0'
-VERSION_TUPLE = (2, 4, 0)
+VERSION_TUPLE = (2, 8, 0)
+VERSION = '.'.join(map(str, VERSION_TUPLE))
 
 # Tk windowing system (auto set up in init.py)
 WIN_SYSTEM = 'x11'                      # win32, x11, aqua, classic
@@ -63,8 +63,8 @@ if os.name == 'posix':
     DATA_DIRS = [
         '/usr/share/PySolFC',
         '/usr/local/share/PySolFC',
-        '/usr/games/PySolFC',
-        '/usr/local/games/PySolFC',
+        '/usr/share/games/PySolFC',
+        '/usr/local/share/games/PySolFC',
         ]
 if os.name == 'nt':
     pass
