@@ -21,23 +21,20 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
 import os
 import time
-from six.moves import tkinter
-from . import ttk
-from six.moves import tkinter_font
 
-# PySol imports
-from pysollib.mygettext import _
 from pysollib.mfxutil import KwStruct
 from pysollib.mfxutil import format_time
-# from pysollib.util import *
-from pysollib.stats import PysolStatsFormatter, ProgressionFormatter
+from pysollib.mygettext import _
 from pysollib.settings import TOP_TITLE
-
-# Toolkit imports
+from pysollib.stats import ProgressionFormatter, PysolStatsFormatter
 from pysollib.ui.tktile.tkutil import bind, loadImage
+
+from six.moves import tkinter
+from six.moves import tkinter_font
+from six.moves import tkinter_ttk as ttk
+
 from .tkwidget import MfxDialog, MfxMessageDialog
 
 
@@ -371,7 +368,8 @@ class TreeFormatter(PysolStatsFormatter):
             self.parent_window.games[id] = t8
 
         total, played, won, lost, time_, moves, perc = self.getStatSummary()
-        text = _("Total (%d out of %d games)") % (played, total)
+        text = _("Total (%(played)d out of %(total)d games)") % {
+            'played': played, 'total': total}
         id = self.tree.insert("", "end", text=text,
                               values=(won+lost, won, lost, time_, moves, perc))
         self.parent_window.tree_items.append(id)
