@@ -21,31 +21,24 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
 import os
 import time
+
+from pysollib.mfxutil import KwStruct, kwdefault
+from pysollib.mfxutil import format_time
+from pysollib.mygettext import _
+from pysollib.settings import TOP_TITLE
+from pysollib.stats import ProgressionFormatter, PysolStatsFormatter
+from pysollib.ui.tktile.tkutil import bind, loadImage
+
 from six.moves import tkinter
 from six.moves import tkinter_font
 
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.mfxutil import kwdefault, KwStruct
-from pysollib.mfxutil import format_time
-# from pysollib.util import *
-from pysollib.stats import PysolStatsFormatter, ProgressionFormatter
-from pysollib.settings import TOP_TITLE
-
-# Toolkit imports
-from pysollib.ui.tktile.tkutil import bind, loadImage
 from .tkwidget import MfxDialog, MfxMessageDialog
 from .tkwidget import MfxScrolledCanvas
 
+# FIXME - this file is a quick hack and needs a rewrite
 
-# FIXME - this file a quick hack and needs a rewrite
-
-# ************************************************************************
-# *
-# ************************************************************************
 
 class SingleGame_StatsDialog(MfxDialog):
     def __init__(self, parent, title, app, player, gameid, **kw):
@@ -170,7 +163,6 @@ class SingleGame_StatsDialog(MfxDialog):
                 x, ty[1]-dy, text="%d%%" % (100-pw), anchor="ne", font=tfont,
                 fill=fg)
 
-
 #      def _createChart3DBar(self, canvas, perc, x, y, p, col):
 #          if perc < 0.005:
 #              return
@@ -204,11 +196,6 @@ class SingleGame_StatsDialog(MfxDialog):
 #          draw_line(5, 6)
 #          draw_line(6, 7)
 #          draw_line(7, 4)
-
-    #
-    # charts
-    #
-
 #      def createSimpleChart(self, app, won, lost, text):
 #          #c, tfont, fg = self._createChartInit(frame, 300, 100, text)
 #          self._createChartInit(300, 100, text)
@@ -217,7 +204,6 @@ class SingleGame_StatsDialog(MfxDialog):
 #          tx = (90, 180, 210)
 #          ty = (21, 41, 75)
 #          self._createChartTexts(tx, ty, won, lost)
-
 #      def create3DBarChart(self, app, won, lost, text):
 #          image = app.gimages.stats[0]
 #          iw, ih = image.width(), image.height()
@@ -424,7 +410,8 @@ class CanvasFormatter(PysolStatsFormatter):
         #
         y += self.h
         total, played, won, lost, time_, moves, perc = self.getStatSummary()
-        s = _("Total (%d out of %d games)") % (played, total)
+        s = _("Total (%(played)d out of %(total)d games)") % {
+            'played': played, 'total': total}
         self.pstats(y, (s, won+lost, won, lost, time_, moves, perc))
 
     def writeLog(self, player, prev_games):
