@@ -21,13 +21,9 @@
 #
 # ---------------------------------------------------------------------------##
 
-from six.moves import tkinter
-
-from pysollib.settings import TOOLKIT, USE_TILE
 from pysollib.macosx.appSupport import hideTkConsole
-from pysollib.winsystems.common import base_init_root_window, BaseTkSettings
-if USE_TILE:
-    from pysollib.tile import ttk
+from pysollib.settings import TOOLKIT, USE_TILE
+from pysollib.winsystems.common import BaseTkSettings, base_init_root_window
 
 
 def init_root_window(root, app):
@@ -37,15 +33,7 @@ def init_root_window(root, app):
     if TOOLKIT == 'gtk':
         pass
     elif USE_TILE:
-        style = ttk.Style(root)
-        color = style.lookup('.', 'background')
-        if color:
-            root.tk_setPalette(color)   # for non-ttk widgets
-
-        if app.opt.tile_theme == 'aqua':
-            # standard Tk scrollbars work on OS X, but ttk ones look weird
-            ttk.Scrollbar = tkinter.Scrollbar
-
+        pass
     else:                               # pure Tk
         # root.option_add(...)
         pass
